"""Module setting global parameters for the application, such as logging, cache, route generation, etc."""

import logging
import os
from pathlib import Path


LOCATION_PREFIX = Path('src')
PARAMETERS_DIR = LOCATION_PREFIX / 'parameters'
AMENITY_SELECTORS_PATH = PARAMETERS_DIR / 'amenity_selectors.yaml'
LANDMARK_PARAMETERS_PATH = PARAMETERS_DIR / 'landmark_parameters.yaml'
OPTIMIZER_PARAMETERS_PATH = PARAMETERS_DIR / 'optimizer_parameters.yaml'


cache_dir_string = os.getenv('OSM_CACHE_DIR', './cache')
OSM_CACHE_DIR = Path(cache_dir_string)


# if we are in a debug (local) session, set verbose and rich logging
debug = os.getenv('DEBUG', "false") == "true"
if os.getenv('KUBERNETES_SERVICE_HOST', None) is not None:
    # in that case we want to log to stdout and also to loki
    from loki_logger_handler.loki_logger_handler import LokiLoggerHandler
    loki_url = os.getenv('LOKI_URL')
    if loki_url is None:
        raise ValueError("LOKI_URL environment variable is not set")
    
    loki_handler = LokiLoggerHandler(
        url = loki_url,
        labels = {'app': 'anyway', 'environment': 'production' if debug else 'staging'}
    )
    print(f"Logging to Loki at {loki_url} with {loki_handler.labels} and {debug=}")
    if debug:
        # we need to silence the debug logs made by the loki handler
        logging.getLogger('urllib3.connectionpool').setLevel(logging.INFO)

        logging.basicConfig(
            level=logging.DEBUG,
            handlers=[loki_handler, logging.StreamHandler()]
        )
    else:
        logging.basicConfig(
            level=logging.INFO,
            handlers=[loki_handler, logging.StreamHandler()]
        )
else:
    # in that case we are local and we want to log to stdout only, but make it pretty
    from rich.logging import RichHandler
    logging.basicConfig(
        level=logging.DEBUG,
        format='%(asctime)s - %(name)s - %(levelname)s - %(message)s',
        handlers=[RichHandler()]
    )


MEMCACHED_HOST_PATH = os.getenv('MEMCACHED_HOST_PATH', None)
if MEMCACHED_HOST_PATH == "none":
    MEMCACHED_HOST_PATH = None
